# encoding: utf-8
"""
@project: djangoModel->service_register
@author: 孙楷炎
@Email: sky4834@163.com
@synopsis: 请注意所有模块下面必须填写，模块详情。各模块开发者需注意
@created_time: 2023/1/12 14:29
"""

# 参考案例
short_desc = """
公共服务，非主业务模块。所有函数库保持xj_common模块为最新。
其他模块更系统函数或自定义方法，请同步到该模块utils目录下面。该模块主要提供通用服务功能，供所有模块使用。
"""

module_info = {
    "module_name": "xj_common",
    "module_type": "SUB_MODULE",
    "description": short_desc,
}
